"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.builder = exports.desc = exports.aliases = exports.command = void 0;
const helpers_1 = require("../../../helpers");
// tslint:disable-next-line: no-var-requires
const logger = helpers_1.createNewLogger('codefresh:list:organizations');
exports.command = 'organizations';
exports.aliases = ['orgs'];
exports.desc = 'Get a list of organizations that the authenticated user is related to';
exports.builder = (yargs) => yargs
    .usage('Usage: $0 list organizations [options]')
    .example(`$0 list ${exports.command}`, 'Will list all organizations the authenticated user is affiliated with');
exports.handler = async (argv) => {
    const provider = argv.provider;
    const output = argv.output;
    const limit = argv.limit;
    logger.debug(`output=${output}`);
    logger.debug(`limit=${limit}`);
    const [err, orgs] = await helpers_1.to(provider.listOrganizations({ limit }));
    if (err) {
        helpers_1.exitWithError(`failed to get the list of organizations, ${err}`);
    }
    if (output) {
        await helpers_1.writeResultsToFile(output, JSON.stringify(orgs));
    }
    else {
        console.log(JSON.stringify(orgs));
    }
};
//# sourceMappingURL=organizations.cmd.js.map