"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.builder = exports.desc = exports.aliases = exports.command = void 0;
const helpers_1 = require("../../../helpers");
// tslint:disable-next-line: no-var-requires
const logger = helpers_1.createNewLogger('codefresh:list:webhooks');
exports.command = 'webhooks';
exports.aliases = ['wh'];
exports.desc = 'Get a list of the repository webhooks';
exports.builder = (yargs) => yargs
    .usage('Usage: $0 list webhooks [options]')
    .option('owner', {
    alias: 'o',
    demandOption: helpers_1.errormsg `must provide "owner" option`,
    describe: 'The name of the owner of the git repository',
    type: 'string'
})
    .option('repo', {
    alias: 'r',
    demandOption: helpers_1.errormsg `must provide "repo" option`,
    describe: 'The name of the git repository',
    type: 'string'
})
    .example(`$0 list ${exports.command} -o some-owner -r some-repo`, 'Will list all webhooks from repo: "some-owner/some-repo"')
    .example(`$0 list ${exports.command} -o some-owner -r some-repo -l 40`, 'Will list up to 40 webhooks from repo: "some-owner/some-repo"');
exports.handler = async (argv) => {
    const owner = argv.owner;
    const repo = argv.repo;
    const provider = argv.provider;
    const output = argv.output;
    const limit = argv.limit;
    logger.debug(`owner=${owner}`);
    logger.debug(`output=${output}`);
    logger.debug(`limit=${limit}`);
    const [err, webhooks] = await helpers_1.to(provider.listWebhooks({ owner, repo, limit }));
    if (err) {
        helpers_1.exitWithError(`failed to get the list of webhooks of repository: "${owner}/${repo}", ${err}`);
    }
    if (output) {
        await helpers_1.writeResultsToFile(output, JSON.stringify(webhooks));
    }
    else {
        console.log(JSON.stringify(webhooks));
    }
};
//# sourceMappingURL=webhooks.cmd.js.map