import { ProviderName, Provider, Branch, Repository, Webhook } from './types';
export default class Bitbucket implements Provider {
    private baseUrl;
    private authenticationHeader;
    private timeout;
    private agent?;
    constructor(opts: {
        password: string;
        username?: string;
        refreshToken?: string;
        expires?: number;
        type: 'basic' | 'oauth2' | 'PAT';
        apiURL?: string;
        timeout?: number;
        insecure?: boolean;
    });
    getName(): ProviderName;
    private performAPICall;
    fetchRawFile(opts: {
        owner: string;
        repo: string;
        ref: string;
        path: string;
    }): Promise<string>;
    getBranch(opts: {
        owner: string;
        repo: string;
        branch: string;
    }): Promise<Branch>;
    getRepository(opt: {
        owner: string;
        repo: string;
    }): Promise<Repository>;
    listBranches(opt: {
        owner: string;
        repo: string;
        limit?: number | undefined;
    }): Promise<Branch[]>;
    listRepositoriesForOwner(opt: {
        owner: string;
        sort?: 'name' | 'pushed' | 'created';
        direction?: 'desc' | 'asc';
        limit?: number;
    }): Promise<Repository[]>;
    createRepositoryWebhook(opt: {
        owner: string;
        repo: string;
        endpoint: string;
        secret: string;
    }): Promise<Webhook>;
    listWebhooks(opt: {
        owner: string;
        repo: string;
        limit?: number;
    }): Promise<Webhook[]>;
    deleteRepositoryWebhook(opt: {
        owner: string;
        repo: string;
        hookId: number;
    }): Promise<void>;
    listRepositoriesWithAffiliation(opt: {
        affiliation: string;
        sort?: 'name' | 'pushed' | 'created';
        direction?: 'desc' | 'asc';
        limit?: number;
    }): Promise<Repository[]>;
    listOrganizations(opt: {
        limit?: number;
    }): Promise<string[]>;
    listRepositoriesForOrganization(opt: {
        organization: string;
        sort?: 'name' | 'pushed' | 'created';
        direction?: 'desc' | 'asc';
        limit?: number;
    }): Promise<Repository[]>;
    createCommitStatus(opt: {
        owner: string;
        repo: string;
        sha: string;
        targetUrl: string;
        state: string;
        description: string;
        context: string;
    }): Promise<void>;
}
